import { n as Report, c as ConfigLoader, H as HtmlValidate, a as ConfigData } from './core.js';
export { A as AttributeData, Z as AttributeEvent, f as CSSStyleDeclaration, aa as CompatibilityOptions, $ as ConditionalEvent, C as Config, a as ConfigData, b as ConfigError, c as ConfigLoader, I as ConfigReadyEvent, a2 as DOMLoadEvent, a3 as DOMReadyEvent, s as DeferredMessage, a0 as DirectiveEvent, a1 as DoctypeEvent, D as DynamicValue, Y as ElementReadyEvent, G as Event, F as EventCallback, E as EventDump, B as EventHandler, a6 as FileSystemConfigLoader, a7 as Formatter, e as HtmlElement, H as HtmlValidate, a5 as ListenEventMap, L as Location, q as Message, k as MetaCopyableProperty, M as MetaData, i as MetaElement, j as MetaTable, N as NodeClosed, y as Parser, x as Plugin, P as ProcessElementContext, n as Report, o as Reporter, r as Result, R as Rule, l as RuleDocumentation, h as SchemaValidationError, S as Severity, m as Source, J as SourceReadyEvent, d as StaticConfigLoader, W as TagCloseEvent, V as TagEndEvent, Q as TagOpenEvent, X as TagReadyEvent, O as TagStartEvent, w as TemplateExtractor, T as TextNode, g as TokenDump, K as TokenEvent, t as TransformContext, u as Transformer, a4 as TriggerEventMap, U as UserError, _ as WhitespaceEvent, a9 as compatibilityCheck, p as configPresets, a8 as formatterFactory, z as ruleExists, v as version } from './core.js';
import 'ajv';
import 'ajv/dist/types';

interface ExpandOptions {
    /**
     * Working directory. Defaults to `process.cwd()`.
     */
    cwd?: string;
    /**
     * List of extensions to search for when expanding directories. Extensions
     * should be passed without leading dot, e.g. "html" instead of ".html".
     */
    extensions?: string[];
}

interface InitResult {
    filename: string;
}

interface CLIOptions {
    configFile?: string;
    rules?: string | string[];
}
/**
 * @public
 */
declare class CLI {
    private options;
    private config;
    private loader;
    private ignored;
    /**
     * Create new CLI helper.
     *
     * Can be used to create tooling with similar properties to bundled CLI
     * script.
     */
    constructor(options?: CLIOptions);
    /**
     * Returns list of files matching patterns and are not ignored. Filenames will
     * have absolute paths.
     *
     * @public
     */
    expandFiles(patterns: string[], options?: ExpandOptions): string[];
    getFormatter(formatters: string): (report: Report) => string;
    /**
     * Initialize project with a new configuration.
     *
     * A new `.htmlvalidate.json` file will be placed in the path provided by
     * `cwd`.
     */
    init(cwd: string): Promise<InitResult>;
    /**
     * Searches ".htmlvalidateignore" files from filesystem and returns `true` if
     * one of them contains a pattern matching given filename.
     */
    isIgnored(filename: string): boolean;
    /**
     * Clear cache.
     *
     * Previously fetched [[HtmlValidate]] instances must either be fetched again
     * or call [[HtmlValidate.flushConfigCache]].
     */
    clearCache(): void;
    /**
     * Get HtmlValidate instance with configuration based on options passed to the
     * constructor.
     *
     * @internal
     */
    getLoader(): ConfigLoader;
    /**
     * Get HtmlValidate instance with configuration based on options passed to the
     * constructor.
     *
     * @public
     */
    getValidator(): HtmlValidate;
    /**
     * @internal
     */
    getConfig(): ConfigData;
}

export { CLI };
